@@ -10,8 +10,8 @@ module VagrantPlugins
         end
 
         def call(env)
-          env[:ui].info('Vagrant-libvirt plugin removed box only from you LOCAL ~/.vagrant/boxes directory')
-          env[:ui].info('From libvirt storage pool you have to delete image manually(virsh, virt-manager or by any other tool)')
+          env[:ui].info('Vagrant-libvirt plugin removed box only from your LOCAL ~/.vagrant/boxes directory')
+          env[:ui].info('From Libvirt storage pool you have to delete image manually(virsh, virt-manager or by any other tool)')
           @app.call(env)
         end
       end
