@@ -13,20 +13,17 @@ module VagrantPlugins
           env[:domain_name] = build_domain_name(env)
 
           begin
-            @logger.info("Looking for domain #{env[:domain_name]} through list " \
-                         "#{env[:machine].provider.driver.connection.servers.all}")
+            @logger.info("Looking for domain #{env[:domain_name]}")
             # Check if the domain name is not already taken
 
-            domain = ProviderLibvirt::Util::Collection.find_matching(
-              env[:machine].provider.driver.connection.servers.all, env[:domain_name]
+            domain = env[:machine].provider.driver.connection.servers.all(
+              name: env[:domain_name]
             )
-          rescue Fog::Errors::Error => e
+          rescue Libvirt::RetrieveError => e
             @logger.info(e.to_s)
             domain = nil
           end
 
-          @logger.info("Looking for domain #{env[:domain_name]}")
-
           unless domain.nil?
             raise ProviderLibvirt::Errors::DomainNameExists,
                   domain_name: env[:domain_name]
@@ -41,7 +38,7 @@ module VagrantPlugins
         # parsable and sortable by epoch time
         # @example
         #   development-centos-6-chef-11_1404488971_3b7a569e2fd7c554b852
-        # @return [String] libvirt domain name
+        # @return [String] Libvirt domain name
         def build_domain_name(env)
           config = env[:machine].provider_config
           domain_name =
@@ -51,7 +48,7 @@ module VagrantPlugins
               # don't have any prefix, not even "_"
               ''
             else
-              config.default_prefix.to_s.dup.concat('_')
+              config.default_prefix.to_s.dup
             end
           domain_name << env[:machine].name.to_s
           domain_name.gsub!(/[^-a-z0-9_\.]/i, '')
