@@ -67,6 +67,8 @@ module VagrantPlugins
       attr_accessor :default_prefix
 
       # Domain specific settings used while creating new domain.
+      attr_accessor :title
+      attr_accessor :description
       attr_accessor :uuid
       attr_accessor :memory
       attr_accessor :nodeset
@@ -197,6 +199,8 @@ module VagrantPlugins
         @system_uri      = UNSET_VALUE
 
         # Domain specific settings.
+        @title             = UNSET_VALUE
+        @description       = UNSET_VALUE
         @uuid              = UNSET_VALUE
         @memory            = UNSET_VALUE
         @nodeset           = UNSET_VALUE
@@ -600,7 +604,9 @@ module VagrantPlugins
           cache: options[:cache] || 'default',
           allow_existing: options[:allow_existing],
           shareable: options[:shareable],
-          serial: options[:serial]
+          serial: options[:serial],
+          pool: options[:pool], # overrides storage_pool setting for additional disks
+          wwn: options[:wwn],
         }
 
         @disks << disk # append
@@ -618,14 +624,21 @@ module VagrantPlugins
         @qemu_env.merge!(options)
       end
 
-      # code to generate URI from a config moved out of the connect action
-      def _generate_uri
+      # code to generate URI from from either the LIBVIRT_URI environment
+      # variable or a config moved out of the connect action
+      def _generate_uri(qemu_use_session)
+
+        # If the LIBVIRT_DEFAULT_URI var is set, we'll use that
+        if ENV.fetch('LIBVIRT_DEFAULT_URI', '') != ""
+          return ENV['LIBVIRT_DEFAULT_URI']
+        end
+
         # builds the Libvirt connection URI from the given driver config
         # Setup connection uri.
         uri = @driver.dup
         virt_path = case uri
                     when 'qemu', 'kvm'
-                      @qemu_use_session ? '/session' : '/system'
+                      qemu_use_session ? '/session' : '/system'
                     when 'openvz', 'uml', 'phyp', 'parallels'
                       '/system'
                     when '@en', 'esx'
@@ -643,31 +656,37 @@ module VagrantPlugins
           uri << '+ssh://'
           uri << @username + '@' if @username
 
-          uri << if @host
-                   @host
-                 else
-                   'localhost'
-                 end
+          uri << ( @host ? @host : 'localhost' )
         else
           uri << '://'
           uri << @host if @host
         end
 
         uri << virt_path
-        uri << '?no_verify=1'
+
+        params = {'no_verify' => '1'}
 
         if @id_ssh_key_file
           # set ssh key for access to Libvirt host
-          uri << "\&keyfile="
           # if no slash, prepend $HOME/.ssh/
-          @id_ssh_key_file.prepend("#{`echo ${HOME}`.chomp}/.ssh/") if @id_ssh_key_file !~ /\A\//
-          uri << @id_ssh_key_file
+          @id_ssh_key_file.prepend("#{ENV['HOME']}/.ssh/") if @id_ssh_key_file !~ /\A\//
+          params['keyfile'] = @id_ssh_key_file
         end
         # set path to Libvirt socket
-        uri << "\&socket=" + @socket if @socket
+        params['socket'] = @socket if @socket
+
+        uri << "?" + params.map{|pair| pair.join('=')}.join('&')
         uri
       end
 
+      def _parse_uri(uri)
+        begin
+          URI.parse(uri)
+        rescue
+          raise "@uri set to invalid uri '#{uri}'"
+        end
+      end
+
       def finalize!
         @driver = 'kvm' if @driver == UNSET_VALUE
         @host = nil if @host == UNSET_VALUE
@@ -691,12 +710,25 @@ module VagrantPlugins
         @management_network_domain = nil if @management_network_domain == UNSET_VALUE
         @system_uri      = 'qemu:///system' if @system_uri == UNSET_VALUE
 
-        @qemu_use_session = false if @qemu_use_session == UNSET_VALUE
+        # If uri isn't set then let's build one from various sources.
+        # Default to passing false for qemu_use_session if it's not set.
+        if @uri == UNSET_VALUE
+          @uri = _generate_uri(@qemu_use_session == UNSET_VALUE ? false : @qemu_use_session)
+        end
 
-        # generate a URI if none is supplied
-        @uri = _generate_uri if @uri == UNSET_VALUE
+        # Set qemu_use_session based on the URI if it wasn't set by the user
+        if @qemu_use_session == UNSET_VALUE
+          uri = _parse_uri(@uri)
+          if (uri.scheme.start_with? "qemu") && (uri.path.include? "session")
+            @qemu_use_session = true
+          else
+            @qemu_use_session = false
+          end
+        end
 
         # Domain specific settings.
+        @title = '' if @title == UNSET_VALUE
+        @description = '' if @description == UNSET_VALUE
         @uuid = '' if @uuid == UNSET_VALUE
         @memory = 512 if @memory == UNSET_VALUE
         @nodeset = nil if @nodeset == UNSET_VALUE
@@ -814,6 +846,14 @@ module VagrantPlugins
       def validate(machine)
         errors = _detected_errors
 
+        # The @uri and @qemu_use_session should not conflict
+        uri = _parse_uri(@uri)
+        if (uri.scheme.start_with? "qemu") && (uri.path.include? "session")
+          if @qemu_use_session != true
+            errors << "the URI and qemu_use_session configuration conflict: uri:'#{@uri}' qemu_use_session:'#{@qemu_use_session}'"
+          end
+        end
+
         machine.provider_config.disks.each do |disk|
           if disk[:path] && (disk[:path][0] == '/')
             errors << "absolute volume paths like '#{disk[:path]}' not yet supported"
